==> google-cloud-cpp-1.36.0.tar.gz: google-cloud-cpp-1.36.0/google/cloud/monitoring/README.md <==
# Cloud Monitoring API C++ Client Library

:construction:

This directory contains an idiomatic C++ client library for the
[Cloud Monitoring API][cloud-service-docs], a service to manage your Cloud
Monitoring data and configurations. This library is used to interact with the
Cloud Monitoring API directly. If you are looking to instrument your application
for Cloud Monitoring, we recommend using
[OpenTelemetry](https://opentelemetry.io) or a similar framework.

This library is **experimental**. Its APIs are subject to change without notice.

Please note that the Google Cloud C++ client libraries do **not** follow
[Semantic Versioning](https://semver.org/).

## Supported Platforms

* Windows, macOS, Linux
* C++11 (and higher) compilers (we test with GCC >= 5.4, Clang >= 6.0, and
  MSVC >= 2017)
* Environments with or without exceptions
* Bazel and CMake builds

## Documentation

* Official documentation about the [Cloud Monitoring API][cloud-service-docs] service
* [Reference doxygen documentation][doxygen-link] for each release of this
  client library
* Detailed header comments in our [public `.h`][source-link] files

[cloud-service-docs]: https://cloud.google.com/monitoring
[doxygen-link]: https://googleapis.dev/cpp/google-cloud-monitoring/latest/
[source-link]: https://github.com/googleapis/google-cloud-cpp/tree/main/google/cloud/monitoring

## Quickstart

The [quickstart/](quickstart/README.md) directory contains a minimal environment
to get started using this client library in a larger project. The following
"Hello World" program is used in this quickstart, and should give you a taste of
this library.

<!-- inject-quickstart-start -->
```cc
#include "google/cloud/monitoring/alert_policy_client.h"
#include "google/cloud/project.h"
#include <iostream>
#include <stdexcept>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace monitoring = ::google::cloud::monitoring;
  auto client = monitoring::AlertPolicyServiceClient(
      monitoring::MakeAlertPolicyServiceConnection());

  auto const project = google::cloud::Project(argv[1]);
  for (auto a : client.ListAlertPolicies(project.FullName())) {
    if (!a) throw std::runtime_error(a.status().message());
    std::cout << a->DebugString() << "\n";
  }

  return 0;
} catch (std::exception const& ex) {
  std::cerr << "Standard exception raised: " << ex.what() << "\n";
  return 1;
}
```
<!-- inject-quickstart-end -->

* Packaging maintainers or developers who prefer to install the library in a
  fixed directory (such as `/usr/local` or `/opt`) should consult the
  [packaging guide](/doc/packaging.md).
* Developers wanting to use the libraries as part of a larger CMake or Bazel
  project should consult the [quickstart guides](#quickstart) for the library
  or libraries they want to use.
* Developers wanting to compile the library just to run some of the examples or
  tests should read the current document.
* Contributors and developers to `google-cloud-cpp` should consult the guide to
  [setup a development workstation][howto-setup-dev-workstation].

[howto-setup-dev-workstation]: /doc/contributor/howto-guide-setup-development-workstation.md

## Contributing changes

See [`CONTRIBUTING.md`](../../../CONTRIBUTING.md) for details on how to
contribute to this project, including how to build and test your changes
as well as how to properly format your code.

## Licensing

Apache 2.0; see [`LICENSE`](../../../LICENSE) for details.

==> google-cloud-cpp-2.19.0.tar.gz: google-cloud-cpp-2.19.0/google/cloud/monitoring/README.md <==
# Cloud Monitoring API C++ Client Library

This directory contains an idiomatic C++ client library for the
[Cloud Monitoring API][cloud-service-docs], a service to manage your Cloud
Monitoring data and configurations. This library is used to interact with the
Cloud Monitoring API directly. If you are looking to instrument your application
for Cloud Monitoring, we recommend using
[OpenTelemetry](https://opentelemetry.io) or a similar framework.

While this library is **GA**, please note that the Google Cloud C++ client
libraries do **not** follow [Semantic Versioning](https://semver.org/).

## Quickstart

The [quickstart/](quickstart/README.md) directory contains a minimal environment
to get started using this client library in a larger project. The following
"Hello World" program is used in this quickstart, and should give you a taste of
this library.

For detailed instructions on how to build and install this library, see the
top-level [README](/README.md#building-and-installing).

<!-- inject-quickstart-start -->

```cc
#include "google/cloud/monitoring/v3/alert_policy_client.h"
#include "google/cloud/project.h"
#include <iostream>

int main(int argc, char* argv[]) try {
  if (argc != 2) {
    std::cerr << "Usage: " << argv[0] << " project-id\n";
    return 1;
  }

  namespace monitoring = ::google::cloud::monitoring_v3;
  auto client = monitoring::AlertPolicyServiceClient(
      monitoring::MakeAlertPolicyServiceConnection());

  auto const project = google::cloud::Project(argv[1]);
  for (auto a : client.ListAlertPolicies(project.FullName())) {
    if (!a) throw std::move(a).status();
    std::cout << a->DebugString() << "\n";
  }

  return 0;
} catch (google::cloud::Status const& status) {
  std::cerr << "google::cloud::Status thrown: " << status << "\n";
  return 1;
}
```

<!-- inject-quickstart-end -->

## More Information

- Official documentation about the [Cloud Monitoring API][cloud-service-docs]
  service
- [Reference doxygen documentation][doxygen-link] for each release of this
  client library
- Detailed header comments in our [public `.h`][source-link] files

[cloud-service-docs]: https://cloud.google.com/monitoring
[doxygen-link]: https://cloud.google.com/cpp/docs/reference/monitoring/latest/
[source-link]: https://github.com/googleapis/google-cloud-cpp/tree/main/google/cloud/monitoring
